@@ -13,29 +13,23 @@ class bcolors:
     BOLD = '\033[1m'
     UNDERLINE = '\033[4m'
 
-def LPrint(*args,):
+def LPrint(*args,end='\n'):
     caller = getframeinfo(stack()[1][0])
     #print (caller.filename, caller.lineno, caller.function, *args)
-    print (args,'--info>>>\n')
-    print (u'{} {}{},{},{}\n{}'.
+    print (args,'--info>>>   ',end='')
+    print (u'{}{}{},line--{},fn--{}\n{}'.
         format( bcolors.OKBLUE,
-                caller.filename,
+                os.path.basename(caller.filename),
                 bcolors.ENDC,
                 caller.lineno,
                 caller.function,
-                bcolors.ENDC))
+                bcolors.ENDC),end=end)
     
 def test_LPrint(*args,):
     LPrint (u'你好',u'世界',{u'你好':u'世界'},(u'你好',u'世界'))
     
 if __name__=='__main__':
     test_LPrint()
-    LPrint()
-    
-from pygments import highlight
-from pygments.lexers import PythonLexer
-from pygments.formatters import Terminal256Formatter
-from pprint import pformat
 
-def pprint_color(obj):
-    print (highlight(pformat(obj), PythonLexer(), Terminal256Formatter()))
+    
+
